@@ -44,67 +44,80 @@ $inline = 0;
 $code = '';
 $error = '';
 $message = '';
+$sess = new cge_session($this->GetName());
 
 //
 // handle params
 //
-if( isset($params['inline']) )
-  {
-    $inline = (int)$params['inline'];
-  }
-if( isset($params['template']) )
-  {
-    $thetemplate = trim($params['template']);
-  }
+if( isset($params['inline']) ) $inline = (int)$params['inline'];
+if( isset($params['template']) ) $thetemplate = trim($params['template']);
 
 //
 // hande form data
 //
-if( isset($params['promo_submit']) )
-  {
-    if( isset($params['promo_code']) )
-      {
-	$code = trim($params['promo_code']);
-      }
+if( isset($params['promo_submit']) ) {
+  if( isset($params['promo_code']) ) $code = trim($params['promo_code']);
 
-    $error = '';
-    $msg = '';
-    if( $code == '' )
-      {
-	$error = $this->GetPreference('error_empty_code');
-      }
-    else 
-      {
-	// check for code validity
-	if( !promo_ops::is_valid_coupon($code) )
-	  {
-	    $error = $this->GetPreference('error_invalid_code');
-	  }
-	else
-	  {
-	    Promotions::add_coupon($code);
-	    $msg = $this->GetPreference('msg_valid_code');
-	    $code = '';
-	  }
-      }
+  $error = '';
+  $msg = '';
+  if( $code == '' ) {
+    $error = $this->GetPreference('error_empty_code');
   }
-else if( isset($params['promo_clear']) )
-  {
-    Promotions::clear_coupons();
-    $msg = $this->Lang('coupons_cleared');
+  else {
+    // check for code validity
+    if( !promo_ops::is_valid_coupon($code) ) {
+      $error = $this->GetPreference('error_invalid_code');
+    }
+    else {
+      Promotions::add_coupon($code);
+      $msg = $this->GetPreference('msg_valid_code');
+      $code = '';
+    }
   }
 
+  if( $error ) $sess->put('error',$error);
+  if( $msg ) $sess->put('msg',$msg);
+
+  if( isset($params['promo_orig_url']) ) {
+    $url = trim($params['promo_orig_url']);
+    $url = str_replace('amp;','',$url);
+    if( $url ) redirect($url);
+  }
+}
+else if( isset($params['promo_clear']) ) {
+  Promotions::clear_coupons();
+  $msg = $this->Lang('coupons_cleared');
+
+  $sess->put('msg',$msg);
+}
+
 //
 // give everything to smarty
 //
-if( $msg != '' )
-  {
-    $smarty->assign('msg',$msg);
-  }
-if( $error != '' )
-  {
-    $smarty->assign('error',$error);
+if( $sess->exists('msg') ) {
+  $msg = $sess->get('msg');
+  $sess->clear('msg');
+}
+if( $sess->exists('error') ) {
+  $error = $sess->get('error');
+  $sess->clear('error');
+}
+if( $sess->exists('coupons') ) {
+  $coupons = $sess->get('coupons');
+  if( is_array($coupons) && count($coupons) ) {
+    $smarty->assign('coupons',$coupons);
   }
+}
+
+if( isset($msg) && $msg != '' ) {
+  $smarty->assign('msg',$msg);
+}
+if( isset($error) && $error != '' ) {
+  $smarty->assign('error',$error);
+}
+if( !isset($params['promo_orig_url']) ) {
+  $params['promo_orig_url'] = cge_url::current_url();
+}
 $smarty->assign('code',$code);
 $smarty->assign('formstart',
 		$this->CGCreateFormStart($id,'default',$returnid,$params,$inline));
